==> unit-1.1.17-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractNodeNotesTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractNodeNotesTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _42_1_090975452 _42_1_090975452;
	public NodeNotesTemplate._42_1_090975452. NodeNotesTable nodeNotesTable;
	public NodeNotesTemplate._42_1_090975452.NodeNotesTable. NodeNotesTableNameHeading nodeNotesTableNameHeading;
	public NodeNotesTemplate._42_1_090975452.NodeNotesTable.NodeNotesTableNameHeading. _46_40_0871825099 _46_40_0871825099;
	public NodeNotesTemplate._42_1_090975452.NodeNotesTable. NodeNotesTableValueHeading nodeNotesTableValueHeading;
	public NodeNotesTemplate._42_1_090975452.NodeNotesTable.NodeNotesTableValueHeading. _49_41_1754749520 _49_41_1754749520;
	public NodeNotesTemplate._42_1_090975452.NodeNotesTable. NodeNotesTableOperationsHeading nodeNotesTableOperationsHeading;
	public NodeNotesDialog nodeNotesDialog;
	public NodeNotesTemplate.NodeNotesDialog. _58_2_11865488311 _58_2_11865488311;
	public NodeNotesTemplate.NodeNotesDialog. NameField nameField;
	public NodeNotesTemplate.NodeNotesDialog. ValueField valueField;
	public NodeNotesTemplate.NodeNotesDialog. _61_2_11828094277 _61_2_11828094277;
	public NodeNotesTemplate.NodeNotesDialog._61_2_11828094277. Add add;

    public AbstractNodeNotesTemplate(B box) {
        super(box);
        id("nodeNotesTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (_42_1_090975452 == null) _42_1_090975452 = register(new _42_1_090975452(box()).<_42_1_090975452>id("a1647139244").owner(AbstractNodeNotesTemplate.this));
		if (_42_1_090975452 != null) nodeNotesTable = _42_1_090975452.nodeNotesTable;
		if (nodeNotesTable != null) nodeNotesTableNameHeading = _42_1_090975452.nodeNotesTable.nodeNotesTableNameHeading;
		if (nodeNotesTableNameHeading != null) _46_40_0871825099 = _42_1_090975452.nodeNotesTable.nodeNotesTableNameHeading._46_40_0871825099;
		if (nodeNotesTable != null) nodeNotesTableValueHeading = _42_1_090975452.nodeNotesTable.nodeNotesTableValueHeading;
		if (nodeNotesTableValueHeading != null) _49_41_1754749520 = _42_1_090975452.nodeNotesTable.nodeNotesTableValueHeading._49_41_1754749520;
		if (nodeNotesTable != null) nodeNotesTableOperationsHeading = _42_1_090975452.nodeNotesTable.nodeNotesTableOperationsHeading;
		if (nodeNotesDialog == null) nodeNotesDialog = register(new NodeNotesDialog(box()).<NodeNotesDialog>id("a_987498814").owner(AbstractNodeNotesTemplate.this));
		if (nodeNotesDialog != null) _58_2_11865488311 = nodeNotesDialog._58_2_11865488311;
		if (nodeNotesDialog != null) nameField = nodeNotesDialog.nameField;
		if (nodeNotesDialog != null) valueField = nodeNotesDialog.valueField;
		if (nodeNotesDialog != null) _61_2_11828094277 = nodeNotesDialog._61_2_11828094277;
		if (_61_2_11828094277 != null) add = nodeNotesDialog._61_2_11828094277.add;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_42_1_090975452 != null) _42_1_090975452.unregister();
	    if (nodeNotesDialog != null) nodeNotesDialog.unregister();
	}

	public class _42_1_090975452 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public NodeNotesTemplate._42_1_090975452. NodeNotesTable nodeNotesTable;

		public _42_1_090975452(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (nodeNotesTable == null) nodeNotesTable = register(new NodeNotesTable(box()).<NodeNotesTable>id("a_1729398965").owner(AbstractNodeNotesTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (nodeNotesTable != null) nodeNotesTable.unregister();
		}

		public class NodeNotesTable extends io.intino.alexandria.ui.displays.components.Table<B, io.intino.alexandria.ui.displays.components.Row, io.intino.goros.unit.box.ui.datasources.model.Note>  {
			public NodeNotesTemplate._42_1_090975452.NodeNotesTable. NodeNotesTableNameHeading nodeNotesTableNameHeading;
			public NodeNotesTemplate._42_1_090975452.NodeNotesTable. NodeNotesTableValueHeading nodeNotesTableValueHeading;
			public NodeNotesTemplate._42_1_090975452.NodeNotesTable. NodeNotesTableOperationsHeading nodeNotesTableOperationsHeading;

			public NodeNotesTable(B box) {
				super(box);

				_pageSize(20);
			}

			@Override
			public void init() {
				super.init();
				if (nodeNotesTableNameHeading == null) nodeNotesTableNameHeading = register(new NodeNotesTableNameHeading(box()).<NodeNotesTableNameHeading>id("a_1764897871").owner(AbstractNodeNotesTemplate.this));
				if (nodeNotesTableValueHeading == null) nodeNotesTableValueHeading = register(new NodeNotesTableValueHeading(box()).<NodeNotesTableValueHeading>id("a_1617921356").owner(AbstractNodeNotesTemplate.this));
				if (nodeNotesTableOperationsHeading == null) nodeNotesTableOperationsHeading = register(new NodeNotesTableOperationsHeading(box()).<NodeNotesTableOperationsHeading>id("a_756116213").owner(AbstractNodeNotesTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (nodeNotesTableNameHeading != null) nodeNotesTableNameHeading.unregister();
				if (nodeNotesTableValueHeading != null) nodeNotesTableValueHeading.unregister();
				if (nodeNotesTableOperationsHeading != null) nodeNotesTableOperationsHeading.unregister();
			}


			public NodeNotesTableRow create(io.intino.goros.unit.box.ui.datasources.model.Note item) {
				NodeNotesTableRow row = new NodeNotesTableRow((UnitBox)box());
				row.id(java.util.UUID.randomUUID().toString());
				row.item(item);
				return row;
			}
			public class NodeNotesTableNameHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
				public NodeNotesTemplate._42_1_090975452.NodeNotesTable.NodeNotesTableNameHeading. _46_40_0871825099 _46_40_0871825099;

				public NodeNotesTableNameHeading(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_46_40_0871825099 == null) _46_40_0871825099 = register(new _46_40_0871825099(box()).<_46_40_0871825099>id("a1503996494").owner(AbstractNodeNotesTemplate.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (_46_40_0871825099 != null) _46_40_0871825099.unregister();
				}

				public class _46_40_0871825099 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public _46_40_0871825099(B box) {
						super(box);
						_value("Nombre");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}
			}

			public class NodeNotesTableValueHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
				public NodeNotesTemplate._42_1_090975452.NodeNotesTable.NodeNotesTableValueHeading. _49_41_1754749520 _49_41_1754749520;

				public NodeNotesTableValueHeading(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_49_41_1754749520 == null) _49_41_1754749520 = register(new _49_41_1754749520(box()).<_49_41_1754749520>id("a_1705265512").owner(AbstractNodeNotesTemplate.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (_49_41_1754749520 != null) _49_41_1754749520.unregister();
				}

				public class _49_41_1754749520 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public _49_41_1754749520(B box) {
						super(box);
						_value("Valor");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}
			}

			public class NodeNotesTableOperationsHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {

				public NodeNotesTableOperationsHeading(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}
	}

	public class NodeNotesDialog extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public NodeNotesTemplate.NodeNotesDialog. _58_2_11865488311 _58_2_11865488311;
		public NodeNotesTemplate.NodeNotesDialog. NameField nameField;
		public NodeNotesTemplate.NodeNotesDialog. ValueField valueField;
		public NodeNotesTemplate.NodeNotesDialog. _61_2_11828094277 _61_2_11828094277;

		public NodeNotesDialog(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_58_2_11865488311 == null) _58_2_11865488311 = register(new _58_2_11865488311(box()).<_58_2_11865488311>id("a_545080977").owner(AbstractNodeNotesTemplate.this));
			if (nameField == null) nameField = register(new NameField(box()).<NameField>id("a2111765490").owner(AbstractNodeNotesTemplate.this));
			if (valueField == null) valueField = register(new ValueField(box()).<ValueField>id("a_104247386").owner(AbstractNodeNotesTemplate.this));
			if (_61_2_11828094277 == null) _61_2_11828094277 = register(new _61_2_11828094277(box()).<_61_2_11828094277>id("a1148948054").owner(AbstractNodeNotesTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_58_2_11865488311 != null) _58_2_11865488311.unregister();
			if (nameField != null) nameField.unregister();
			if (valueField != null) valueField.unregister();
			if (_61_2_11828094277 != null) _61_2_11828094277.unregister();
		}

		public class _58_2_11865488311 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _58_2_11865488311(B box) {
				super(box);
				_value("Añadir nota");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}

		public class NameField extends io.intino.alexandria.ui.displays.components.TextEditable<io.intino.alexandria.ui.displays.notifiers.TextEditableNotifier, B>  {

			public NameField(B box) {
				super(box);
				label("Nombre");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}

		public class ValueField extends io.intino.alexandria.ui.displays.components.TextEditable<io.intino.alexandria.ui.displays.notifiers.TextEditableNotifier, B>  {

			public ValueField(B box) {
				super(box);
				label("Valor");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}

		public class _61_2_11828094277 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public NodeNotesTemplate.NodeNotesDialog._61_2_11828094277. Add add;

			public _61_2_11828094277(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (add == null) add = register(new Add(box()).<Add>id("a_750260733").owner(AbstractNodeNotesTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (add != null) add.unregister();
			}

			public class Add extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, B>  {

				public Add(B box) {
					super(box);
					_title("Añadir");
					_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Button"));
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}
	}
}

==> unit-2.1.5-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractNodeNotesTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractNodeNotesTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _42_1_01822819043 _42_1_01822819043;
	public NodeNotesTemplate._42_1_01822819043. NodeNotesTable nodeNotesTable;
	public NodeNotesTemplate._42_1_01822819043.NodeNotesTable. NodeNotesTableNameHeading nodeNotesTableNameHeading;
	public NodeNotesTemplate._42_1_01822819043.NodeNotesTable.NodeNotesTableNameHeading. _46_40_0871825099 _46_40_0871825099;
	public NodeNotesTemplate._42_1_01822819043.NodeNotesTable. NodeNotesTableValueHeading nodeNotesTableValueHeading;
	public NodeNotesTemplate._42_1_01822819043.NodeNotesTable.NodeNotesTableValueHeading. _49_41_1754749520 _49_41_1754749520;
	public NodeNotesTemplate._42_1_01822819043.NodeNotesTable. NodeNotesTableOperationsHeading nodeNotesTableOperationsHeading;
	public NodeNotesDialog nodeNotesDialog;
	public NodeNotesTemplate.NodeNotesDialog. _58_2_11865488311 _58_2_11865488311;
	public NodeNotesTemplate.NodeNotesDialog. NameField nameField;
	public NodeNotesTemplate.NodeNotesDialog. ValueField valueField;
	public NodeNotesTemplate.NodeNotesDialog. _61_2_11480484409 _61_2_11480484409;
	public NodeNotesTemplate.NodeNotesDialog._61_2_11480484409. Add add;

	public AbstractNodeNotesTemplate(B box) {
		super(box);
		id("nodeNotesTemplate");
	}

	@Override
	public void init() {
		super.init();
		if (_42_1_01822819043 == null) _42_1_01822819043 = register(new _42_1_01822819043(box()).<_42_1_01822819043>id("a_1318830287").owner(AbstractNodeNotesTemplate.this));
		if (_42_1_01822819043 != null) nodeNotesTable = _42_1_01822819043.nodeNotesTable;
		if (nodeNotesTable != null) nodeNotesTableNameHeading = _42_1_01822819043.nodeNotesTable.nodeNotesTableNameHeading;
		if (nodeNotesTableNameHeading != null) _46_40_0871825099 = _42_1_01822819043.nodeNotesTable.nodeNotesTableNameHeading._46_40_0871825099;
		if (nodeNotesTable != null) nodeNotesTableValueHeading = _42_1_01822819043.nodeNotesTable.nodeNotesTableValueHeading;
		if (nodeNotesTableValueHeading != null) _49_41_1754749520 = _42_1_01822819043.nodeNotesTable.nodeNotesTableValueHeading._49_41_1754749520;
		if (nodeNotesTable != null) nodeNotesTableOperationsHeading = _42_1_01822819043.nodeNotesTable.nodeNotesTableOperationsHeading;
		if (nodeNotesDialog == null) nodeNotesDialog = register(new NodeNotesDialog(box()).<NodeNotesDialog>id("a_987498814").owner(AbstractNodeNotesTemplate.this));
		if (nodeNotesDialog != null) _58_2_11865488311 = nodeNotesDialog._58_2_11865488311;
		if (nodeNotesDialog != null) nameField = nodeNotesDialog.nameField;
		if (nodeNotesDialog != null) valueField = nodeNotesDialog.valueField;
		if (nodeNotesDialog != null) _61_2_11480484409 = nodeNotesDialog._61_2_11480484409;
		if (_61_2_11480484409 != null) add = nodeNotesDialog._61_2_11480484409.add;
	}

	@Override
	public void remove() {
		super.remove();
		if (_42_1_01822819043 != null) _42_1_01822819043.unregister();
		if (nodeNotesDialog != null) nodeNotesDialog.unregister();
	}

	public class _42_1_01822819043 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public NodeNotesTemplate._42_1_01822819043. NodeNotesTable nodeNotesTable;

		public _42_1_01822819043(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (nodeNotesTable == null) nodeNotesTable = register(new NodeNotesTable(box()).<NodeNotesTable>id("a_1729398965").owner(AbstractNodeNotesTemplate.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (nodeNotesTable != null) nodeNotesTable.unregister();
		}

		public class NodeNotesTable extends io.intino.alexandria.ui.displays.components.Table<B, io.intino.alexandria.ui.displays.components.Row, io.intino.goros.unit.box.ui.datasources.model.Note>  {
			public NodeNotesTemplate._42_1_01822819043.NodeNotesTable. NodeNotesTableNameHeading nodeNotesTableNameHeading;
			public NodeNotesTemplate._42_1_01822819043.NodeNotesTable. NodeNotesTableValueHeading nodeNotesTableValueHeading;
			public NodeNotesTemplate._42_1_01822819043.NodeNotesTable. NodeNotesTableOperationsHeading nodeNotesTableOperationsHeading;

			public NodeNotesTable(B box) {
				super(box);

				_pageSize(20);
			}

			@Override
			public void init() {
				super.init();
				if (nodeNotesTableNameHeading == null) nodeNotesTableNameHeading = register(new NodeNotesTableNameHeading(box()).<NodeNotesTableNameHeading>id("a_1764897871").owner(AbstractNodeNotesTemplate.this));
				if (nodeNotesTableValueHeading == null) nodeNotesTableValueHeading = register(new NodeNotesTableValueHeading(box()).<NodeNotesTableValueHeading>id("a_1617921356").owner(AbstractNodeNotesTemplate.this));
				if (nodeNotesTableOperationsHeading == null) nodeNotesTableOperationsHeading = register(new NodeNotesTableOperationsHeading(box()).<NodeNotesTableOperationsHeading>id("a_756116213").owner(AbstractNodeNotesTemplate.this));
			}

			@Override
			public void unregister() {
				super.unregister();
				if (nodeNotesTableNameHeading != null) nodeNotesTableNameHeading.unregister();
				if (nodeNotesTableValueHeading != null) nodeNotesTableValueHeading.unregister();
				if (nodeNotesTableOperationsHeading != null) nodeNotesTableOperationsHeading.unregister();
			}


			public NodeNotesTableRow create(io.intino.goros.unit.box.ui.datasources.model.Note item) {
				NodeNotesTableRow row = new NodeNotesTableRow((UnitBox)box());
				row.id(java.util.UUID.randomUUID().toString());
				row.item(item);
				return row;
			}
			public class NodeNotesTableNameHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
				public NodeNotesTemplate._42_1_01822819043.NodeNotesTable.NodeNotesTableNameHeading. _46_40_0871825099 _46_40_0871825099;

				public NodeNotesTableNameHeading(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_46_40_0871825099 == null) _46_40_0871825099 = register(new _46_40_0871825099(box()).<_46_40_0871825099>id("a1503996494").owner(AbstractNodeNotesTemplate.this));
				}

				@Override
				public void unregister() {
					super.unregister();
					if (_46_40_0871825099 != null) _46_40_0871825099.unregister();
				}

				public class _46_40_0871825099 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public _46_40_0871825099(B box) {
						super(box);
						_value("Nombre");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
						super.unregister();
					}
				}
			}

			public class NodeNotesTableValueHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
				public NodeNotesTemplate._42_1_01822819043.NodeNotesTable.NodeNotesTableValueHeading. _49_41_1754749520 _49_41_1754749520;

				public NodeNotesTableValueHeading(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_49_41_1754749520 == null) _49_41_1754749520 = register(new _49_41_1754749520(box()).<_49_41_1754749520>id("a_1705265512").owner(AbstractNodeNotesTemplate.this));
				}

				@Override
				public void unregister() {
					super.unregister();
					if (_49_41_1754749520 != null) _49_41_1754749520.unregister();
				}

				public class _49_41_1754749520 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public _49_41_1754749520(B box) {
						super(box);
						_value("Valor");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
						super.unregister();
					}
				}
			}

			public class NodeNotesTableOperationsHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {

				public NodeNotesTableOperationsHeading(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
					super.unregister();
				}
			}
		}
	}

	public class NodeNotesDialog extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public NodeNotesTemplate.NodeNotesDialog. _58_2_11865488311 _58_2_11865488311;
		public NodeNotesTemplate.NodeNotesDialog. NameField nameField;
		public NodeNotesTemplate.NodeNotesDialog. ValueField valueField;
		public NodeNotesTemplate.NodeNotesDialog. _61_2_11480484409 _61_2_11480484409;

		public NodeNotesDialog(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_58_2_11865488311 == null) _58_2_11865488311 = register(new _58_2_11865488311(box()).<_58_2_11865488311>id("a_545080977").owner(AbstractNodeNotesTemplate.this));
			if (nameField == null) nameField = register(new NameField(box()).<NameField>id("a2111765490").owner(AbstractNodeNotesTemplate.this));
			if (valueField == null) valueField = register(new ValueField(box()).<ValueField>id("a_104247386").owner(AbstractNodeNotesTemplate.this));
			if (_61_2_11480484409 == null) _61_2_11480484409 = register(new _61_2_11480484409(box()).<_61_2_11480484409>id("a_1035708630").owner(AbstractNodeNotesTemplate.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (_58_2_11865488311 != null) _58_2_11865488311.unregister();
			if (nameField != null) nameField.unregister();
			if (valueField != null) valueField.unregister();
			if (_61_2_11480484409 != null) _61_2_11480484409.unregister();
		}

		public class _58_2_11865488311 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _58_2_11865488311(B box) {
				super(box);
				_value("Añadir nota");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}
		}

		public class NameField extends io.intino.alexandria.ui.displays.components.TextEditable<io.intino.alexandria.ui.displays.notifiers.TextEditableNotifier, B>  {

			public NameField(B box) {
				super(box);
				label("Nombre");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}
		}

		public class ValueField extends io.intino.alexandria.ui.displays.components.TextEditable<io.intino.alexandria.ui.displays.notifiers.TextEditableNotifier, B>  {

			public ValueField(B box) {
				super(box);
				label("Valor");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}
		}

		public class _61_2_11480484409 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public NodeNotesTemplate.NodeNotesDialog._61_2_11480484409. Add add;

			public _61_2_11480484409(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (add == null) add = register(new Add(box()).<Add>id("a_750260733").owner(AbstractNodeNotesTemplate.this));
			}

			@Override
			public void unregister() {
				super.unregister();
				if (add != null) add.unregister();
			}

			public class Add extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, B>  {

				public Add(B box) {
					super(box);
					_title("Añadir");
					_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Button"));
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
					super.unregister();
				}
			}
		}
	}
}
